@@ -1,4 +1,4 @@
-"ln.paleoTS" <-
+`ln.paleoTS` <-
 function (y)
 # returns paleoTS, with data approx ln-transformed
 # mean(ln[y])= ln(mean[y]); var(ln[y])=(sd[y]/mean[y])^2
