@@ -1,5 +1,5 @@
-"pool.var" <-
-function(y,nn=NULL)
+`pool.var` <-
+function(y,nn=NULL, ret.paleoTS=FALSE)
 # calc pooled variance
 # y is either a paleoTS object, or an array of variances
 {
@@ -9,6 +9,12 @@ function(y,nn=NULL)
  else
     vp<- sum(y*(nn-1))/sum(nn-1)
     
- return (vp)
+ if (ret.paleoTS)
+ {
+   yn<- y
+   yn$vv<- rep(vp, length(y$mm))
+   return(yn)		
+ }
+ else { return (vp)}
 }
 
